@@ -1,7 +1,7 @@
 from .lzhw_alg import LZHW, decompress_from_file
 from .lzhw_df import CompressedDF, decompress_df_from_file
 from .huffman_coding import huffman_coding
-#from .lz20 import lz20
+from lz77c import *
 from lz20c import lz20
 from .lz78 import lz78
 from lzw_c import lzw_compress, lzw_decompress
\ No newline at end of file
